@@ -7,7 +7,7 @@ use warnings;
 require Exporter;
 use vars qw(@ISA @EXPORT);
 @ISA = qw(Exporter);
-@EXPORT = qw(require_CPAN_Distribution skip_on_darwin_without_homebrew);
+@EXPORT = qw(require_CPAN_Distribution skip_on_darwin_without_homebrew skip_on_os);
 
 sub require_CPAN_Distribution () {
     if (!eval { require CPAN::Distribution; 1 }) {
@@ -21,4 +21,12 @@ sub skip_on_darwin_without_homebrew () {
     }
 }
 
+sub skip_on_os ($;$) {
+    my($os, $message) = @_;
+    if ($^O eq $os) {
+	$message ||= "Does not work on $os";
+	Test::More::plan(skip_all => $message);
+    }
+}
+
 1;
